sqlobject.sqlite.sqliteconnection module — SQLObject 3.9.1 documentation

# sqlobject.sqlite.sqliteconnection module

class `sqlobject.sqlite.sqliteconnection.` `ErrorMessage`(e)

  Bases: `str`

class `sqlobject.sqlite.sqliteconnection.` `SQLiteConnection`(filename, autoCommit=1, **kw)

  Bases: `sqlobject.dbconnection.DBAPI`

  `addColumn`(tableName, column)
  `close`()
  `columnsFromSchema`(tableName, soClass)
  `createColumn`(soClass, col)
  `createEmptyDatabase`()

    Create an empty database.

  `createIDColumn`(soClass)
  `createIndexSQL`(soClass, index)
  `createReferenceConstraint`(soClass, col)
  `dbName` = 'sqlite'
  `delColumn`(sqlmeta, column)
  `dropDatabase`()
  `getConnection`()
  `guessClass`(t)
  `joinSQLType`(join)
  `listDatabases`()
  `listTables`()
  `makeConnection`()
  `makeMemoryConnection`()
  `oldUri`()
  `recreateTableWithoutColumn`(sqlmeta, column)
  `releaseConnection`(conn, explicit=False)
  `schemes` = ['sqlite']
  `supportTransactions` = True
  `tableExists`(tableName)
  `uri`()